import { Wallet } from "../wallet";
import { CChain } from "./cchain";
import { NetworkBased } from "./core";
import { PChain } from "./pchain";
import { AfterTxSubmissionCallback, BeforeTxSignatureCallback, BeforeTxSubmissionCallback } from "./callback";
import { Constants } from "./constants";
import { Balance, FtsoDelegate as FtsoDelegate, Stake } from "./balance";
import { FlareContract } from "./contract";
/**
 * The main class used for interaction with the Flare network.
 */
export declare class Network extends NetworkBased {
    /**
     * Network constructor.
     * @param constants Network constants of class {@link Cosntants}.
     */
    constructor(constants: Constants);
    /**
     * The main Flare network.
     */
    static readonly FLARE: Network;
    /**
     * The canary Flare network.
     */
    static readonly SONGBIRD: Network;
    /**
     * The test Flare network.
     */
    static readonly COSTON2: Network;
    /**
     * The test canary Flare network.
     */
    static readonly COSTON: Network;
    protected _cchain: CChain;
    protected _pchain: PChain;
    /**
     * Derives the C-chain address from the given public key.
     * @param publicKey A public key in hexadecimal encoding.
     * @returns The C-chain address in checksummed hexadecimal encoding.
     */
    getCAddress(publicKey: string): string;
    /**
     * Derives the P-chain address from the given public key.
     * @param publicKey A public key in hexadecimal encoding.
     * @returns The P-chain address in bech32 encoding.
     */
    getPAddress(publicKey: string): string;
    /**
     * Returns balance information related the given public key.
     * @param publicKey A public key in hexadecimal encoding.
     * @returns The object of type {@link Balance}.
     */
    getBalance(publicKey: string): Promise<Balance>;
    /**
     * Returns balance on the C-chain.
     * @param publicKeyOrAddress A public key or a C-chain address in hexadecimal encoding.
     * @returns The balance in wei corresponding to the public key or address.
     */
    getBalanceOnC(publicKeyOrAddress: string): Promise<bigint>;
    /**
     * Returns balance wrapped on the C-chain.
     * @param publicKeyOrAddress A public key or a C-chain address in hexadecimal encoding.
     * @returns The balance in wei corresponding to the public key or address.
     */
    getBalanceWrappedOnC(publicKeyOrAddress: string): Promise<bigint>;
    /**
     * Returns balance on the P-chain.
     * @param publicKey A public key in hexadecimal encoding.
     * @returns The balance in wei corresponding to the public key.
     */
    getBalanceOnP(publicKey: string): Promise<bigint>;
    /**
     * Returns balance not imported to the C-chain.
     * @param publicKey A public key in hexadecimal encoding.
     * @returns The balance in wei corresponding to the public key.
     */
    getBalanceNotImportedToC(publicKey: string): Promise<bigint>;
    /**
     * Returns balance not imported to the P-chain.
     * @param publicKey A public key in hexadecimal encoding.
     * @returns The balance in wei corresponding to the public key.
     */
    getBalanceNotImportedToP(publicKey: string): Promise<bigint>;
    /**
     * Returns balance staked on the P-chain.
     * @param publicKey A public key in hexadecimal encoding.
     * @returns The balance in wei corresponding to the public key.
     */
    getBalanceStakedOnP(publicKey: string): Promise<bigint>;
    /**
     * Returns information about stakes on the P-chain.
     * @param publicKey A public key in hexadecimal encoding (optional).
     * @returns The array of stakes on the P-chain
     * (corresponding to the given public key if given).
     */
    getStakesOnP(publicKey?: string): Promise<Array<Stake>>;
    /**
     * Returns FTSO delegates on the C-chain.
     * @param publicKeyOrAddress A public key or a C-chain address in hexadecimal encoding.
     * @returns The array of objects of type {@link FtsoDelegate} that contains information
     * about the FTSO delegates and shares that the address specified by `publicKeyOrAddress`
     * currently delegates to.
     */
    getFtsoDelegatesOf(publicKeyOrAddress: string): Promise<Array<FtsoDelegate>>;
    /**
     * Transfers wallet funds to a given recipient on the C-chain.
     * @param wallet An instance of the class implementing the interface {@link Wallet} that contains:
     * - the function `getCAddress` or `getPublicKey`, and
     * - the function `signCTransaction`, `signAndSubmitCTransaction` or `signDigest`.
     * @param recipient A C-chain address of the transfer recipient.
     * @param amount An amount in wei to be wrapped on the C-chain.
     */
    transferNative(wallet: Wallet, recipient: string, amount: bigint): Promise<void>;
    /**
     * Attempts to transfer all wallet funds to a given recipient on the C-chain.
     * @param wallet An instance of the class implementing the interface {@link Wallet} that contains:
     * - the function `getCAddress` or `getPublicKey`, and
     * - the function `signCTransaction`, `signAndSubmitCTransaction` or `signDigest`.
     * @param recipient A C-chain address of the transfer recipient.
     * @remark As fees on the C-chain are subjected to change, a certain amount of dust may be left on
     * the account after the transaction is executed.
     */
    transferAllNative(wallet: Wallet, recipient: string): Promise<void>;
    /**
     * Wraps wallet funds on the C-chain.
     * @param wallet An instance of the class implementing the interface {@link Wallet} that contains:
     * - the function `getCAddress` or `getPublicKey`, and
     * - the function `signCTransaction`, `signAndSubmitCTransaction` or `signDigest`.
     * @param amount An amount in wei to be wrapped on the C-chain.
     */
    wrapNative(wallet: Wallet, amount: bigint): Promise<void>;
    /**
     * Unwraps wallet funds on the C-chain.
     * @param wallet An instance of the class implementing the interface {@link Wallet} that contains:
     * - the function `getCAddress` or `getPublicKey`, and
     * - the function `signCTransaction`, `signAndSubmitCTransaction` or `signDigest`.
     * @param amount An amount in wei to be unwrapped on the C-chain.
     * If the amount is not given, all wrapped funds are unwrapped.
     */
    unwrapToNative(wallet: Wallet, amount?: bigint): Promise<void>;
    /**
     * Transfers wrapped wallet funds to a given recipient on the C-chain.
     * @param wallet An instance of the class implementing the interface {@link Wallet} that contains:
     * - the function `getCAddress` or `getPublicKey`, and
     * - the function `signCTransaction`, `signAndSubmitCTransaction` or `signDigest`.
     * @param recipient A C-chain address of the transfer recipient.
     * @param amount An amount in wei to be wrapped on the C-chain.
     */
    transferWrapped(wallet: Wallet, recipient: string, amount: bigint): Promise<void>;
    /**
     * Gets a list of all official Flare network contracts.
     * @returns The array of type {@link FlareContract}.
     */
    getFlareContracts(): Promise<Array<FlareContract>>;
    /**
     * Invokes a method call on a specified EVM contract.
     * @param contract Contract address or a Flare network name.
     * @param abi Application binary interface corresponding to contract or method.
     * @param method Name of the method.
     * @param params Parameters of the method.
     * @returns The result of the call.
     */
    invokeContractCallOnC(contract: string, abi: string, method: string, ...params: any[]): Promise<any>;
    /**
     * Invokes a method transaction on a specified EVM contract.
     * @param wallet An instance of the class implementing the interface {@link Wallet} that contains:
     * - the function `getCAddress` or `getPublicKey`, and
     * - the function `signCTransaction`, `signAndSubmitCTransaction` or `signDigest`.
     * @param contract Contract address or a Flare network name.
     * @param abi Application binary interface corresponding to contract or method.
     * @param method Name of the method.
     * @param value Native coin value to send in the transaction.
     * @param params Parameters of the method.
     */
    invokeContractMethodOnC(wallet: Wallet, contract: string, abi: string, method: string, value: bigint, ...params: any[]): Promise<void>;
    /**
     * Transfers wallet funds from the C-chain to the P-chain.
     * @remarks The transfer generally requires two transactions:
     * export from the C-chain and import to the P-chain.
     * @param wallet An instance of the class implementing the interface {@link Wallet} that contains:
     * - the function `getPublicKey`, and
     * - the function `signPTransaction`, `signDigest` or `signEthMessage`.
     * @param amount An amount in wei to be transferred to the P-chain.
     */
    transferToP(wallet: Wallet, amount: bigint): Promise<void>;
    /**
     * Transfers wallet funds from the P-chain to the C-chain.
     * @remarks The transfer generally requires two transactions:
     * export from the P-chain and import to the C-chain.
     * @param wallet An instance of the class implementing the interface {@link Wallet} that contains:
     * - the function `getPublicKey`, and
     * - the function `signPTransaction`, `signDigest` or `signEthMessage`.
     * @param amount An amount in wei to be transferred to the C-chain.
     * Note that this amount is reduced by the C-chain transaction fee.
     * If the amount is not given, all available balance on the P-chain is transferred.
     */
    transferToC(wallet: Wallet, amount?: bigint): Promise<void>;
    /**
     * Exports wallet funds from the C-chain address.
     * @param wallet An instance of the class implementing the interface {@link Wallet} that contains:
     * - the function `getPublicKey`, and
     * - the function `signPTransaction`, `signDigest` or `signEthMessage`.
     * @param amount An amount in qwei to be exported.
     * @param baseFee A base C-chain transaction fee in wei to be used for transaction (optional).
     */
    exportFromC(wallet: Wallet, amount: bigint, baseFee?: bigint): Promise<void>;
    /**
     * Imports all unimported wallet funds to the C-chain address.
     * @param wallet An instance of the class implementing the interface {@link Wallet} that contains:
     * - the function `getPublicKey`, and
     * - the function `signPTransaction`, `signDigest` or `signEthMessage`.
     * @param baseFee A base C-chain transaction fee in wei to be used for transaction (optional).
     */
    importToC(wallet: Wallet, baseFee?: bigint): Promise<void>;
    /**
     * Exports wallet funds from the P-chain address.
     * @param wallet An instance of the class implementing the interface {@link Wallet} that contains:
     * - the function `getPublicKey`, and
     * - the function `signPTransaction`, `signDigest` or `signEthMessage`.
     * @param amount An amount in qwei to be exported.
     */
    exportFromP(wallet: Wallet, amount: bigint): Promise<void>;
    /**
     * Imports all unimported wallet funds to the P-chain address.
     * @param wallet An instance of the class implementing the interface {@link Wallet} that contains:
     * - the function `getPublicKey`, and
     * - the function `signPTransaction`, `signDigest` or `signEthMessage`.
     */
    importToP(wallet: Wallet): Promise<void>;
    /**
     * Delegates wallet funds on the P-chain.
     * @param wallet An instance of the class implementing the interface {@link Wallet} that contains:
     * - the function `getPublicKey`, and
     * - the function `signPTransaction`, `signDigest` or `signEthMessage`.
     * @param amount The amount in wei to be delegated.
     * @param nodeId The code of the validator's node to delegate to.
     * @param startTime The seconds from the Unix epoch marking the start of the delegation.
     * @param endTime The seconds from the Unix epoch marking the end of the delegation.
     */
    delegateOnP(wallet: Wallet, amount: bigint, nodeId: string, startTime: bigint, endTime: bigint): Promise<void>;
    /**
     * Delegates vote power to FTSO providers on the C-chain.
     * @param wallet An instance of the class implementing the interface {@link Wallet} that contains:
     * - the function `getCAddress` or `getPublicKey`, and
     * - the function `signCTransaction`, `signAndSubmitCTransaction` or `signDigest`.
     * @param delegate1 A C-chain address representing the first FTSO delegate.
     * @param shareBP1 A share of vote power in base points to delegate to the first delegate.
     * @param delegate2 A C-chain address representing the second FTSO delegate (optional).
     * @param shareBP2 A share of vote power in base points to delegate to the second delegate (optional).
     * @remark The shares are specified in units between 0 and 10000 with a unit representing 0.01%.
     * The sum of `shareBP1` and `shareBP2` should not be larger than 10000.
     * The transaction invoked by this call undelegates all previous delegations.
     */
    delegateToFtso(wallet: Wallet, delegate1: string, shareBP1: bigint, delegate2?: string, shareBP2?: bigint): Promise<void>;
    /**
     * Undelegates vote power from FTSO providers on the C-chain.
     * @param wallet An instance of the class implementing the interface {@link Wallet} that contains:
     * - the function `getCAddress` or `getPublicKey`, and
     * - the function `signCTransaction`, `signAndSubmitCTransaction` or `signDigest`.
     */
    undelegateFromFtso(wallet: Wallet): Promise<void>;
    /**
     * Returns the current base transaction fee on the C-chain.
     * @returns The base fee in wei.
     */
    getBaseTxFeeOnC(): Promise<bigint>;
    /**
     * Returns the default transaction fee on the P-chain
     * @returns The default fee in wei.
     */
    getDefaultTxFeeOnP(): bigint;
    /**
     * Sets the node's RPC address used for connecting to the blockchains.
     * @param rpc RPC address.
     */
    setRpc(rpc: string): void;
    /**
     * Sets the callback that is invoked before each transaction signature request.
     * @param callback The callback function of type {@link BeforeTxSignatureCallback}.
     * Use `null` to remove the callback.
     */
    setBeforeTxSignatureCallback(callback: BeforeTxSignatureCallback): void;
    /**
     * Sets the callback that is invoked before each transaction submission to the network.
     * @param callback The callback function of type {@link BeforeTxSubmissionCallback}.
     * Use `null` to remove the callback.
     */
    setBeforeTxSubmissionCallback(callback: BeforeTxSubmissionCallback): void;
    /**
     * Sets the callback that is invoked after each transaction submission to the network.
     * @param callback The callback function of type {@link AfterTxSubmissionCallback}.
     * Use `null` to remove the callback.
     */
    setAfterTxSubmissionCallback(callback: AfterTxSubmissionCallback): void;
    private _getCAddress;
    private _getAccount;
    private _shouldBeGweiInteger;
}
//# sourceMappingURL=network.d.ts.map